@@ -387,14 +387,18 @@ class CreateEventBusRequest(AbstractModel):
         :type EventBusName: str
         :param Description: 事件集描述，不限字符类型，200字符描述以内
         :type Description: str
+        :param SaveDays: EB存储时长
+        :type SaveDays: int
         """
         self.EventBusName = None
         self.Description = None
+        self.SaveDays = None
 
 
     def _deserialize(self, params):
         self.EventBusName = params.get("EventBusName")
         self.Description = params.get("Description")
+        self.SaveDays = params.get("SaveDays")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -863,6 +867,50 @@ class DeleteTransformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ESTargetParams(AbstractModel):
+    """描述Es规则目标
+
+    """
+
+    def __init__(self):
+        r"""
+        :param NetMode: 网络连接类型
+        :type NetMode: str
+        :param IndexPrefix: 索引前缀
+        :type IndexPrefix: str
+        :param RotationInterval: es日志轮换粒度
+        :type RotationInterval: str
+        :param OutputMode: DTS事件配置
+        :type OutputMode: str
+        :param IndexSuffixMode: DTS索引配置
+        :type IndexSuffixMode: str
+        :param IndexTemplateType: es模版类型
+        :type IndexTemplateType: str
+        """
+        self.NetMode = None
+        self.IndexPrefix = None
+        self.RotationInterval = None
+        self.OutputMode = None
+        self.IndexSuffixMode = None
+        self.IndexTemplateType = None
+
+
+    def _deserialize(self, params):
+        self.NetMode = params.get("NetMode")
+        self.IndexPrefix = params.get("IndexPrefix")
+        self.RotationInterval = params.get("RotationInterval")
+        self.OutputMode = params.get("OutputMode")
+        self.IndexSuffixMode = params.get("IndexSuffixMode")
+        self.IndexTemplateType = params.get("IndexTemplateType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class EtlFilter(AbstractModel):
     """描述如何过滤数据
 
@@ -902,11 +950,15 @@ class Event(AbstractModel):
         :type Type: str
         :param Subject: 事件来源详细描述，可自定义，选填。云服务默认为标准qcs资源表示语法：qcs::dts:ap-guangzhou:appid/uin:xxx
         :type Subject: str
+        :param Time: 事件发生的毫秒时间戳，
+time.Now().UnixNano()/1e6
+        :type Time: int
         """
         self.Source = None
         self.Data = None
         self.Type = None
         self.Subject = None
+        self.Time = None
 
 
     def _deserialize(self, params):
@@ -914,6 +966,7 @@ class Event(AbstractModel):
         self.Data = params.get("Data")
         self.Type = params.get("Type")
         self.Subject = params.get("Subject")
+        self.Time = params.get("Time")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1466,12 +1519,12 @@ class ListTargetsRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param RuleId: 事件规则ID
-        :type RuleId: str
         :param EventBusId: 事件集ID
         :type EventBusId: str
         :param OrderBy: 根据哪个字段进行返回结果排序,支持以下字段：AddTime（创建时间）, ModTime（修改时间）
         :type OrderBy: str
+        :param RuleId: 事件规则ID
+        :type RuleId: str
         :param Limit: 返回数量，默认为20，最大值为100。
         :type Limit: int
         :param Offset: 分页偏移量，默认为0。
@@ -1479,18 +1532,18 @@ class ListTargetsRequest(AbstractModel):
         :param Order: 以升序还是降序的方式返回结果，可选值 ASC（升序） 和 DESC（降序）
         :type Order: str
         """
-        self.RuleId = None
         self.EventBusId = None
         self.OrderBy = None
+        self.RuleId = None
         self.Limit = None
         self.Offset = None
         self.Order = None
 
 
     def _deserialize(self, params):
-        self.RuleId = params.get("RuleId")
         self.EventBusId = params.get("EventBusId")
         self.OrderBy = params.get("OrderBy")
+        self.RuleId = params.get("RuleId")
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
         self.Order = params.get("Order")
@@ -1615,6 +1668,56 @@ class PublishEventResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class PutEventsRequest(AbstractModel):
+    """PutEvents请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EventList: 事件列表
+        :type EventList: list of Event
+        :param EventBusId: 事件集ID
+        :type EventBusId: str
+        """
+        self.EventList = None
+        self.EventBusId = None
+
+
+    def _deserialize(self, params):
+        if params.get("EventList") is not None:
+            self.EventList = []
+            for item in params.get("EventList"):
+                obj = Event()
+                obj._deserialize(item)
+                self.EventList.append(obj)
+        self.EventBusId = params.get("EventBusId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class PutEventsResponse(AbstractModel):
+    """PutEvents返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class RetryPolicy(AbstractModel):
     """用来描述一个ckafka投递目标的重试策略
 
@@ -1842,10 +1945,13 @@ class TargetDescription(AbstractModel):
         :type SCFParams: :class:`tencentcloud.eb.v20210416.models.SCFParams`
         :param CkafkaTargetParams: Ckafka参数
         :type CkafkaTargetParams: :class:`tencentcloud.eb.v20210416.models.CkafkaTargetParams`
+        :param ESTargetParams: ElasticSearch参数
+        :type ESTargetParams: :class:`tencentcloud.eb.v20210416.models.ESTargetParams`
         """
         self.ResourceDescription = None
         self.SCFParams = None
         self.CkafkaTargetParams = None
+        self.ESTargetParams = None
 
 
     def _deserialize(self, params):
@@ -1856,6 +1962,9 @@ class TargetDescription(AbstractModel):
         if params.get("CkafkaTargetParams") is not None:
             self.CkafkaTargetParams = CkafkaTargetParams()
             self.CkafkaTargetParams._deserialize(params.get("CkafkaTargetParams"))
+        if params.get("ESTargetParams") is not None:
+            self.ESTargetParams = ESTargetParams()
+            self.ESTargetParams._deserialize(params.get("ESTargetParams"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2035,16 +2144,28 @@ class UpdateEventBusRequest(AbstractModel):
         :type Description: str
         :param EventBusName: 事件集名称，只能包含字母、数字、下划线、连字符，以字母开头，以数字或字母结尾，2~60个字符
         :type EventBusName: str
+        :param SaveDays: EB日志存储时长
+        :type SaveDays: int
+        :param LogTopicId: EB日志主题ID
+        :type LogTopicId: str
+        :param EnableStore: 是否开启存储
+        :type EnableStore: bool
         """
         self.EventBusId = None
         self.Description = None
         self.EventBusName = None
+        self.SaveDays = None
+        self.LogTopicId = None
+        self.EnableStore = None
 
 
     def _deserialize(self, params):
         self.EventBusId = params.get("EventBusId")
         self.Description = params.get("Description")
         self.EventBusName = params.get("EventBusName")
+        self.SaveDays = params.get("SaveDays")
+        self.LogTopicId = params.get("LogTopicId")
+        self.EnableStore = params.get("EnableStore")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -2086,6 +2207,8 @@ class UpdateRuleRequest(AbstractModel):
         :type Enable: bool
         :param Description: 规则描述，不限字符类型，200字符描述以内。
         :type Description: str
+        :param EventPattern: 参考：[事件模式](https://cloud.tencent.com/document/product/1359/56084)
+        :type EventPattern: str
         :param RuleName: 事件规则名称，只能包含字母、数字、下划线、连字符，以字母开头，以数字或字母结尾，2~60个字符
         :type RuleName: str
         """
@@ -2093,6 +2216,7 @@ class UpdateRuleRequest(AbstractModel):
         self.EventBusId = None
         self.Enable = None
         self.Description = None
+        self.EventPattern = None
         self.RuleName = None
 
 
@@ -2101,6 +2225,7 @@ class UpdateRuleRequest(AbstractModel):
         self.EventBusId = params.get("EventBusId")
         self.Enable = params.get("Enable")
         self.Description = params.get("Description")
+        self.EventPattern = params.get("EventPattern")
         self.RuleName = params.get("RuleName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
